@@ -8,9 +8,10 @@ import (
 )
 
 func TestFormats(t *testing.T) {
-	assert.Contains(t, Formats, "json")
-	assert.Contains(t, Formats, "toml")
-	assert.Contains(t, Formats, "yaml")
+	assert.Contains(t, FormatsByName, "json")
+	assert.Contains(t, FormatsByName, "toml")
+	assert.Contains(t, FormatsByName, "yaml")
+	assert.NotContains(t, FormatsByName, "yml")
 }
 
 func TestFormatRoundTrip(t *testing.T) {
@@ -23,7 +24,6 @@ func TestFormatRoundTrip(t *testing.T) {
 	}
 
 	for _, format := range []Format{
-		formatGzippedJSON{},
 		formatJSON{},
 		formatTOML{},
 		formatYAML{},
