@@ -47,16 +47,12 @@ const (
 )
 
 var (
+	lineEndingRx                    = regexp.MustCompile(`(?m)(?:\r\n|\r|\n)`)
+	modifyTemplateRx                = regexp.MustCompile(`(?m)^.*chezmoi:modify-template.*$(?:\r?\n)?`)
 	templateDirectiveRx             = regexp.MustCompile(`(?m)^.*?chezmoi:template:(.*)$(?:\r?\n)?`)
 	templateDirectiveKeyValuePairRx = regexp.MustCompile(`\s*(\S+)=("(?:[^"]|\\")*"|\S+)`)
 )
 
-type TemplateOptions struct {
-	LeftDelimiter  string
-	RightDelimiter string
-	Options        []string
-}
-
 // An External is an external source.
 type External struct {
 	Type       ExternalType `json:"type" toml:"type" yaml:"type"`
@@ -109,7 +105,7 @@ type SourceState struct {
 	templateData            map[string]any
 	templateFuncs           template.FuncMap
 	templateOptions         []string
-	templates               map[string]*template.Template
+	templates               map[string]*Template
 	externals               map[RelPath]*External
 	ignoredRelPaths         map[RelPath]struct{}
 }
@@ -254,7 +250,7 @@ func NewSourceState(options ...SourceStateOption) *SourceState {
 		priorityTemplateData: make(map[string]any),
 		userTemplateData:     make(map[string]any),
 		templateOptions:      DefaultTemplateOptions,
-		templates:            make(map[string]*template.Template),
+		templates:            make(map[string]*Template),
 		externals:            make(map[RelPath]*External),
 		ignoredRelPaths:      make(map[RelPath]struct{}),
 	}
@@ -670,8 +666,8 @@ func (s *SourceState) ExecuteTemplateData(options ExecuteTemplateDataOptions) ([
 		return nil, err
 	}
 
-	for name, t := range s.templates {
-		tmpl, err = tmpl.AddParseTree(name, t.Tree)
+	for _, t := range s.templates {
+		tmpl, err = tmpl.AddParseTree(t)
 		if err != nil {
 			return nil, err
 		}
@@ -684,11 +680,7 @@ func (s *SourceState) ExecuteTemplateData(options ExecuteTemplateDataOptions) ([
 		defer delete(chezmoiTemplateData, "sourceFile")
 	}
 
-	builder := strings.Builder{}
-	if err = tmpl.ExecuteTemplate(&builder, options.Name, templateData); err != nil {
-		return nil, err
-	}
-	return []byte(builder.String()), nil
+	return tmpl.Execute(templateData)
 }
 
 // ForEach calls f for each source state entry.
@@ -1254,12 +1246,9 @@ func (s *SourceState) addTemplatesDir(ctx context.Context, templatesDirAbsPath A
 			templateRelPath := templateAbsPath.MustTrimDirPrefix(templatesDirAbsPath)
 			name := templateRelPath.String()
 
-			tmpl, err := ParseTemplate(
-				name,
-				contents,
-				s.templateFuncs,
-				TemplateOptions{Options: append([]string(nil), s.templateOptions...)},
-			)
+			tmpl, err := ParseTemplate(name, contents, s.templateFuncs, TemplateOptions{
+				Options: append([]string(nil), s.templateOptions...),
+			})
 			if err != nil {
 				return err
 			}
@@ -1537,6 +1526,35 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 				return
 			}
 
+			// If the modifier contains chezmoi:modify-template then execute it
+			// as a template.
+			if matches := modifyTemplateRx.FindAllSubmatchIndex(modifierContents, -1); matches != nil {
+				sourceFile := sourceRelPath.String()
+				templateContents := removeMatches(modifierContents, matches)
+				var tmpl *Template
+				tmpl, err = ParseTemplate(sourceFile, templateContents, s.templateFuncs, TemplateOptions{
+					Options: append([]string(nil), s.templateOptions...),
+				})
+				if err != nil {
+					return
+				}
+
+				// Temporarily set .chezmoi.stdin to the current contents and
+				// .chezmoi.sourceFile to the name of the template.
+				templateData := s.TemplateData()
+				if chezmoiTemplateData, ok := templateData["chezmoi"].(map[string]any); ok {
+					chezmoiTemplateData["stdin"] = string(currentContents)
+					chezmoiTemplateData["sourceFile"] = sourceFile
+					defer func() {
+						delete(chezmoiTemplateData, "stdin")
+						delete(chezmoiTemplateData, "sourceFile")
+					}()
+				}
+
+				contents, err = tmpl.Execute(templateData)
+				return
+			}
+
 			// Write the modifier to a temporary file.
 			var tempFile *os.File
 			if tempFile, err = os.CreateTemp("", "*."+fileAttr.TargetName); err != nil {
@@ -2176,56 +2194,6 @@ func (e *External) OriginString() string {
 	return e.URL + " defined in " + e.sourceAbsPath.String()
 }
 
-// ParseTemplate parses a template named name from data with the given funcs and
-// templateOptions.
-func ParseTemplate(
-	name string, data []byte, funcs template.FuncMap, templateOptions TemplateOptions,
-) (*template.Template, error) {
-	contents := templateOptions.parseDirectives(data)
-	return template.New(name).
-		Option(templateOptions.Options...).
-		Delims(templateOptions.LeftDelimiter, templateOptions.RightDelimiter).
-		Funcs(funcs).
-		Parse(string(contents))
-}
-
-// parseDirectives updates o by parsing all template directives in data and
-// returns data with the lines containing directives removed. The lines are
-// removed so that any delimiters do not break template parsing.
-func (o *TemplateOptions) parseDirectives(data []byte) []byte {
-	directiveMatches := templateDirectiveRx.FindAllSubmatchIndex(data, -1)
-	if directiveMatches == nil {
-		return data
-	}
-
-	// Parse options from directives.
-	for _, directiveMatch := range directiveMatches {
-		keyValuePairMatches := templateDirectiveKeyValuePairRx.FindAllSubmatch(data[directiveMatch[2]:directiveMatch[3]], -1)
-		for _, keyValuePairMatch := range keyValuePairMatches {
-			key := string(keyValuePairMatch[1])
-			value := maybeUnquote(string(keyValuePairMatch[2]))
-			switch key {
-			case "left-delimiter":
-				o.LeftDelimiter = value
-			case "right-delimiter":
-				o.RightDelimiter = value
-			case "missing-key":
-				o.Options = append(o.Options, "missingkey="+value)
-			}
-		}
-	}
-
-	// Remove lines containing directives.
-	slices := make([][]byte, 0, len(directiveMatches)+1)
-	slices = append(slices, data[:directiveMatches[0][0]])
-	for i, directiveMatch := range directiveMatches[1:] {
-		slices = append(slices, data[directiveMatches[i][1]:directiveMatch[0]])
-	}
-	slices = append(slices, data[directiveMatches[len(directiveMatches)-1][1]:])
-
-	return bytes.Join(slices, nil)
-}
-
 // allEquivalentDirs returns if sourceStateEntries are all equivalent
 // directories.
 func allEquivalentDirs(sourceStateEntries []SourceStateEntry) bool {
