@@ -26,73 +26,73 @@ func TestGuessDotfilesRepoURL(t *testing.T) {
 		},
 		{
 			arg:                  "codeberg.org/user",
-			expectedHTTPRepoURL:  "https://codeberg.org/user/dotfiles.git",
+			expectedHTTPRepoURL:  "https://user@codeberg.org/user/dotfiles.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@codeberg.org:user/dotfiles.git",
 		},
 		{
 			arg:                  "codeberg.org/user/dots",
-			expectedHTTPRepoURL:  "https://codeberg.org/user/dots.git",
+			expectedHTTPRepoURL:  "https://user@codeberg.org/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@codeberg.org:user/dots.git",
 		},
 		{
 			arg:                  "gitlab.com/user",
-			expectedHTTPRepoURL:  "https://gitlab.com/user/dotfiles.git",
+			expectedHTTPRepoURL:  "https://user@gitlab.com/user/dotfiles.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dotfiles.git",
 		},
 		{
 			arg:                  "gitlab.com/user/dots",
-			expectedHTTPRepoURL:  "https://gitlab.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://user@gitlab.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
 			arg:                  "gitlab.com/user/dots.git",
-			expectedHTTPRepoURL:  "https://gitlab.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://user@gitlab.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
 			arg:                  "http://gitlab.com/user/dots.git",
-			expectedHTTPRepoURL:  "http://gitlab.com/user/dots.git",
+			expectedHTTPRepoURL:  "http://user@gitlab.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
 			arg:                  "https://gitlab.com/user/dots.git",
-			expectedHTTPRepoURL:  "https://gitlab.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://user@gitlab.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
 			arg:                  "sr.ht/~user",
-			expectedHTTPRepoURL:  "https://git.sr.ht/~user/dotfiles",
+			expectedHTTPRepoURL:  "https://user@git.sr.ht/~user/dotfiles",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@git.sr.ht:~user/dotfiles",
 		},
 		{
 			arg:                  "sr.ht/~user/dots",
-			expectedHTTPRepoURL:  "https://git.sr.ht/~user/dots",
+			expectedHTTPRepoURL:  "https://user@git.sr.ht/~user/dots",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@git.sr.ht:~user/dots",
 		},
 		{
 			arg:                  "user",
-			expectedHTTPRepoURL:  "https://github.com/user/dotfiles.git",
+			expectedHTTPRepoURL:  "https://user@github.com/user/dotfiles.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@github.com:user/dotfiles.git",
 		},
 		{
 			arg:                  "user/dots",
-			expectedHTTPRepoURL:  "https://github.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://user@github.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@github.com:user/dots.git",
 		},
 		{
 			arg:                  "user/dots.git",
-			expectedHTTPRepoURL:  "https://github.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://user@github.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@github.com:user/dots.git",
 		},
