@@ -28,6 +28,36 @@ type ioregData struct {
 	value map[string]any
 }
 
+// An emptyPathElementError is returned when a path element is empty.
+type emptyPathElementError struct {
+	index int
+}
+
+func (e emptyPathElementError) Error() string {
+	return fmt.Sprintf("empty path element at index %d", e.index)
+}
+
+// An invalidPathElementTypeError is returned when an element in a path has an invalid type.
+type invalidPathElementTypeError struct {
+	element any
+}
+
+func (e invalidPathElementTypeError) Error() string {
+	return fmt.Sprintf("%v: invalid path element type %T", e.element, e.element)
+}
+
+// An invalidPathTypeError is returned when a path has an invalid type.
+type invalidPathTypeError struct {
+	path any
+}
+
+func (e invalidPathTypeError) Error() string {
+	return fmt.Sprintf("%v: invalid path type %T", e.path, e.path)
+}
+
+// errEmptyPath is returned when a path is empty.
+var errEmptyPath = errors.New("empty path")
+
 // needsQuoteRx matches any string that contains non-printable characters,
 // double quotes, or a backslash.
 var needsQuoteRx = regexp.MustCompile(`[^\x21\x23-\x5b\x5d-\x7e]`)
@@ -165,11 +195,11 @@ func (c *Config) includeTemplateTemplateFunc(filename string, args ...any) strin
 		panic(err)
 	}
 
-	var builder strings.Builder
-	if err := tmpl.Execute(&builder, data); err != nil {
+	result, err := tmpl.Execute(data)
+	if err != nil {
 		panic(err)
 	}
-	return builder.String()
+	return string(result)
 }
 
 func (c *Config) ioregTemplateFunc() map[string]any {
@@ -280,6 +310,38 @@ func (c *Config) replaceAllRegexTemplateFunc(expr, repl, s string) string {
 	return regexp.MustCompile(expr).ReplaceAllString(s, repl)
 }
 
+func (c *Config) setValueAtPathTemplateFunc(path, value, dict any) any {
+	keys, lastKey, err := keysFromPath(path)
+	if err != nil {
+		panic(err)
+	}
+
+	result, ok := dict.(map[string]any)
+	if !ok {
+		result = make(map[string]any)
+	}
+
+	currentMap := result
+	for _, key := range keys {
+		if value, ok := currentMap[key]; ok {
+			if nestedMap, ok := value.(map[string]any); ok {
+				currentMap = nestedMap
+			} else {
+				nestedMap := make(map[string]any)
+				currentMap[key] = nestedMap
+				currentMap = nestedMap
+			}
+		} else {
+			nestedMap := make(map[string]any)
+			currentMap[key] = nestedMap
+			currentMap = nestedMap
+		}
+	}
+	currentMap[lastKey] = value
+
+	return result
+}
+
 func (c *Config) statTemplateFunc(name string) any {
 	switch fileInfo, err := c.fileSystem.Stat(name); {
 	case err == nil:
@@ -341,6 +403,77 @@ func iniSectionToMap(section *ini.Section) map[string]any {
 	return m
 }
 
+func keysFromPath(path any) ([]string, string, error) {
+	switch path := path.(type) {
+	case string:
+		if path == "" {
+			return nil, "", errEmptyPath
+		}
+		keys := strings.Split(path, ".")
+		for i, key := range keys {
+			if key == "" {
+				return nil, "", emptyPathElementError{
+					index: i,
+				}
+			}
+		}
+		return keys[:len(keys)-1], keys[len(keys)-1], nil
+	case []any:
+		if len(path) == 0 {
+			return nil, "", errEmptyPath
+		}
+		keys := make([]string, 0, len(path))
+		for i, pathElement := range path {
+			switch pathElementStr, ok := pathElement.(string); {
+			case !ok:
+				return nil, "", invalidPathElementTypeError{
+					element: pathElement,
+				}
+			case pathElementStr == "":
+				return nil, "", emptyPathElementError{
+					index: i,
+				}
+			default:
+				keys = append(keys, pathElementStr)
+			}
+		}
+		return keys[:len(keys)-1], keys[len(keys)-1], nil
+	case []string:
+		if len(path) == 0 {
+			return nil, "", errEmptyPath
+		}
+		for i, key := range path {
+			if key == "" {
+				return nil, "", emptyPathElementError{
+					index: i,
+				}
+			}
+		}
+		return path[:len(path)-1], path[len(path)-1], nil
+	case nil:
+		return nil, "", errEmptyPath
+	default:
+		return nil, "", invalidPathTypeError{
+			path: path,
+		}
+	}
+}
+
+func nestedMapAtPath(m map[string]any, path any) (map[string]any, string, error) {
+	keys, lastKey, err := keysFromPath(path)
+	if err != nil {
+		return nil, "", err
+	}
+	for _, key := range keys {
+		nestedMap, ok := m[key].(map[string]any)
+		if !ok {
+			return nil, "", nil
+		}
+		m = nestedMap
+	}
+	return m, lastKey, nil
+}
+
 func writeIniMap(w io.Writer, data map[string]any, sectionPrefix string) error {
 	// Write keys in order and accumulate subsections.
 	type subsection struct {
